==> release.12.2.28.1.tgz: cgi-cpn/prontus_tags_export_real.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Exportar tags de Prontus, hacia un arch. XML.
# ---------------------------------------------------------------
# LLAMADAS A ARCHIVOS EXTERNOS.
# ------------------------------
# No registra.
# ---------------------------------------------------------------
# INVOCACIONES ACEPTADAS.
# ------------------------
# Via system desde prontus_tags_export.cgi
# ---------------------------------------------------------------
# PLANTILLAS HTML UTILIZADAS.
# ----------------------------
# No utiliza.
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# TABLAS UTILIZADAS.
# -------------------
# ART (BD prontus)
# ---------------------------------------------------------------

# -------------------------------BEGIN SCRIPT---------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use DBI;
use File::Copy;
use LockFile::Simple;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_lock;
use lib_logproc;
use lib_prontus;
use lib_utils;
##/libs##

# ------------------------------------------------------------------------------
# MAIN.
# -------------

my $PRONTUS_ID;
my ($BD, $LOCK_FILE);
my ($TOT_REGS, $OK_REGS) = (0, 0);
my %FORM;
my $MODO_WEB = 0;
main:{
    lib_utils::setUtf8();
    if (scalar @ARGV < 2) {
        print"Parametros insuficientes Terminando\n";
        print"Uso: $0 [path_server] [nombre_prontus]\nPropósito: generar un archivo xml con los tags para exportar.\n";
        exit;
    }
    if ($ARGV[0] && $ARGV[1]) {
        $prontus_varglb::DIR_SERVER = $ARGV[0];
        $PRONTUS_ID = $ARGV[1];
    }

    # Carga variables de configuracion.
    my $msg_load = lib_utils::load_config_by_id($PRONTUS_ID);
    if ($msg_load ne '') {
        print STDERR "Error: $msg_load\n";
        exit;
    }

    if (! -d $prontus_varglb::DIR_SERVER) {
        print STDERR "ERROR: DIR_SERVER no válido[$prontus_varglb::DIR_SERVER]\n";
        exit;
    }

    # Para el manejo del log de procesamiento
    $lib_logproc::LOG_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tags_export_log.html";
    $lib_logproc::MODO_WEB = $MODO_WEB;

    # Bloqueo
    $LOCK_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/semaforo_tags_export";

    # Detecta semaforo.
    my $lock_obj = &lib_lock::lock_file($LOCK_FILE);
    if (!ref $lock_obj) { # si ya tiene un bloqueo anterior, aborta.
        &finishLoading("Proceso en ejecución. Por favor espere hasta que la exportación anterior termine.");
        lib_logproc::handle_error("Proceso en ejecución. Por favor espere hasta que la exportación anterior termine.");
    }

    # Mysql
    my ($msg_err_bd);
    ($BD, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (! ref($BD)) {
        &finishLoading("ERROR: $msg_err_bd");
        lib_logproc::handle_error("ERROR: $msg_err_bd");
    }

    # Se realiza el proceso y se escribe al Log
    lib_logproc::flush_log();
    lib_logproc::writeRule();
    lib_logproc::add_to_log_count("INICIANDO PROCESO DE EXPORTACION");
    my $registros = &tags_export();
    lib_logproc::add_to_log_count("PROCESO DE EXPORTACION FINALIZADO");
    lib_logproc::writeRule();

    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tags_export.xml", $registros);
    sleep 1;
    lib_logproc::add_to_log("Nro. de registros exportados: $TOT_REGS\nPara bajar el archivo haga click <a href=\"$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tags_export.xml\" download>aqu&iacute;</a>");
    lib_logproc::add_to_log_finish("Operaci&oacute;n finalizada.");

    $BD->disconnect;

    # Elimina el bloqueo y termina ejecucion.
    &lib_lock::unlock_file($lock_obj, $LOCK_FILE);

    # Se termina + el link para descargar
    &finishLoading('');
}

# ------------------------------------------------------------------------------
# SUB-RUTINAS.
# ------------------------------------------------------------------------------
# rotulos tags
sub tags_export {
    my ($sql);
    my ($salida);
        my ($id, $nom, $count, $mostrar, $nom4vistas, $port);
    my ($nom_envistas);
    my ($registros) = "<?xml version='1.0' encoding='utf-8'?>\n<tagsdata>\n";

    lib_logproc::add_to_log_count("Preparando datos a exportar.");

    $sql = "select TAGS_ID, TAGS_TAG, TAGS_COUNT, TAGS_MOSTRAR, TAGS_NOM4VISTAS, TAGS_PORT from TAGS order by TAGS_ID ASC";
    $salida = glib_dbi_03::ejecutar_sql_bind($BD, $sql, \($id, $nom, $count, $mostrar, $nom4vistas, $port));

    lib_logproc::add_to_log_count("Exportaci&oacute;n iniciada");
    lib_logproc::writeRule();

    while ($salida->fetch) {
        # secciones
        glib_str_03::correct_encode_utf8_string($nom);
        glib_str_03::correct_encode_utf8_string($nom4vistas);
        $nom = lib_utils::escape_xml($nom);
        if ($mostrar) { $mostrar = 'SI'; } else { $mostrar = 'NO'; };
        $nom_envistas = &get_nom_envistas($nom4vistas);
        $registros .= "<tag id='$id'>\n"
        . "  <nom>$nom</nom>\n"
        . $nom_envistas
        . "  <count>$count</count>\n"
        . "  <mostrar>$mostrar</mostrar>\n"
            . "  <port>$port</port>\n"
        . "</tag>\n";
        $TOT_REGS++;
        lib_logproc::add_to_log_count("Nro. de registros exportados: $TOT_REGS.");
    }
    $salida->finish;
    $registros .= "</tagsdata>";

    return ($registros);
}

# ------------------------------------------------------------------------------
sub get_nom_envistas {
    my ($nom4vistas) = shift;
    my $nombres;

    foreach my $mv (keys %{$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'MULTIVISTAS'}}) {
        my $nom = lib_prontus::get_nomtax_envista($mv, $nom4vistas);
        $nom = lib_utils::escape_xml($nom);
        $nombres .= "  <nom-$mv>" . $nom . "</nom-$mv>\n";
    }
    return $nombres;
}

# ------------------------------------------------------------------------------
sub finishLoading {
    my $msg = $_[0];
    my $result_file = "$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/result_tags_export.json";
    $msg = '{"status":1, "msg":"'.$msg.'"}';
    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$result_file", $msg);
}

==> release.12.3.1.2.tgz: cgi-cpn/prontus_tags_export_real.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Exportar tags de Prontus, hacia un arch. XML.
# ---------------------------------------------------------------
# LLAMADAS A ARCHIVOS EXTERNOS.
# ------------------------------
# No registra.
# ---------------------------------------------------------------
# INVOCACIONES ACEPTADAS.
# ------------------------
# Via system desde prontus_tags_export.cgi
# ---------------------------------------------------------------
# PLANTILLAS HTML UTILIZADAS.
# ----------------------------
# No utiliza.
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# TABLAS UTILIZADAS.
# -------------------
# ART (BD prontus)
# ---------------------------------------------------------------

# -------------------------------BEGIN SCRIPT---------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use DBI;
use File::Copy;
use JSON;
use LockFile::Simple;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_encodes;
use lib_lang;
use lib_lock;
use lib_logproc;
use lib_prontus;
use lib_utils;
##/libs##

# ------------------------------------------------------------------------------
# MAIN.
# -------------

my $PRONTUS_ID;
my ($BD, $LOCK_FILE);
my ($TOT_REGS, $OK_REGS) = (0, 0);

main:{
    lib_utils::setUp();
    if (scalar @ARGV < 2) {
        print lib_lang::get_message("global_insufficient_arguments")."\n";
        print lib_lang::get_interpolated_message("tags_export_real_use", $0);
        exit;
    }
    if ($ARGV[0] && $ARGV[1]) {
        $prontus_varglb::DIR_SERVER = $ARGV[0];
        $PRONTUS_ID = $ARGV[1];
    }

    # Carga variables de configuracion.
    my $msg_load = lib_utils::load_config_by_id($PRONTUS_ID);
    if ($msg_load ne '') {
        print STDERR "$msg_load\n";
        exit;
    }

    if (! -d $prontus_varglb::DIR_SERVER) {
        print STDERR lib_lang::get_message('global_error_invalid_dir')."\n";
        exit;
    }

    # Para el manejo del log de procesamiento
    $lib_logproc::LOG_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tags_export_log.html";
    $lib_logproc::JS_FILE  = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/result_tags_export.json";

    # Bloqueo
    $LOCK_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/semaforo_tags_export";

    # Detecta semaforo.
    my $lock_obj = &lib_lock::lock_file($LOCK_FILE);
    if (!ref $lock_obj) { # si ya tiene un bloqueo anterior, aborta.
        my $msg = lib_lang::get_message("global_previous_export");
        lib_logproc::finishLoading($msg);
        lib_logproc::handle_error($msg);
    }

    # Mysql
    my ($msg_err_bd);
    ($BD, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (! ref($BD)) {
        lib_logproc::finishLoading($msg_err_bd);
        lib_logproc::handle_error($msg_err_bd);
    }

    # Se realiza el proceso y se escribe al Log
    lib_logproc::writeRule();
    lib_logproc::add_to_log_count(lib_lang::get_message("global_export_starting"));
    my $registros = &tags_export();
    lib_logproc::add_to_log_count(lib_lang::get_message("global_export_ending"));
    lib_logproc::writeRule();

    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tags_export.xml", $registros);
    sleep 1;
    my $msg = lib_lang::get_interpolated_message('global_export_download_message', $TOT_REGS) .
        "<a href=\"$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tags_export.xml\" download> " .
        lib_lang::get_message('global_export_download_message_link') .'</a>';
    lib_logproc::add_to_log($msg);
    lib_logproc::add_to_log_finish(lib_lang::get_message('global_finalized'));

    $BD->disconnect;

    # Elimina el bloqueo y termina ejecucion.
    &lib_lock::unlock_file($lock_obj, $LOCK_FILE);

    # Se termina + el link para descargar
    lib_logproc::finishLoading('');
}

# ------------------------------------------------------------------------------
# SUB-RUTINAS.
# ------------------------------------------------------------------------------
# rotulos tags
sub tags_export {
    my ($id, $nom, $mostrar, $nom4vistas, $port);
    my $nom_envistas;
    my $registros = "<?xml version='1.0' encoding='utf-8'?>\n<tagsdata>\n";

    lib_logproc::add_to_log_count(lib_lang::get_message("global_export_preparing_data"));
    my $tags_table = lib_utils::get_table('tags');
    my $sql = "select tags_id, tags_tag, tags_mostrar, tags_nom4vistas, tags_port from $tags_table order by tags_id asc";
    my $salida = glib_dbi_03::ejecutar_sql_bind($BD, $sql, \($id, $nom, $mostrar, $nom4vistas, $port));

    lib_logproc::add_to_log_count(lib_lang::get_message("global_export_export_started"));
    lib_logproc::writeRule();

    while ($salida->fetch) {
        glib_str_03::correct_encode_utf8_string($nom);
        glib_str_03::correct_encode_utf8_string($nom4vistas);
        $nom = lib_encodes::escape_xml($nom);
        if ($mostrar) { $mostrar = 'SI'; } else { $mostrar = 'NO'; };
        $nom_envistas = &get_nom_envistas($nom4vistas);
        $registros .= "<tag id='$id'>\n"
        . "  <nom>$nom</nom>\n"
        . $nom_envistas
        . "  <mostrar>$mostrar</mostrar>\n"
            . "  <port>$port</port>\n"
        . "</tag>\n";
        $TOT_REGS++;
        lib_logproc::add_to_log_count(lib_lang::get_interpolated_message("global_export_exported_records", $TOT_REGS));
    }
    $salida->finish;
    $registros .= "</tagsdata>";

    return ($registros);
}

# ------------------------------------------------------------------------------
sub get_nom_envistas {
    my ($nom4vistas) = shift;
    my $nombres;

    foreach my $mv (keys %{$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'MULTIVISTA'}}) {
        my $nom = lib_prontus::get_nomtax_envista($mv, $nom4vistas);
        $nom = lib_encodes::escape_xml($nom);
        $nombres .= "  <nom-$mv>" . $nom . "</nom-$mv>\n";
    }
    return $nombres;
}
